;; Generated package description from keymap-popup.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "keymap-popup" "0.4.0" "Described keymaps with popup help" '((emacs "29.1")) :commit "d0b50926a186d2de72aa12c6d6b06e384731865a" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("convenience") :url "https://codeberg.org/thanosapollo/emacs-keymap-popup")
